Scalene

Select a profile (.json)
advanced options
Proposed optimizations
Enter an OpenAI key to enable:
Optimize runtime performance
Optimize memory efficiency
Include GPU optimizations
Click on an explosion (💥) to see proposed optimizations for a region of code,
or on a lightning bolt (⚡) to propose optimizations for a specific line.
Click again to generate a different one.
Note that optimizations are AI-generated and may not be correct.

Profile your Python code with Scalene, then select the generated file `profile.json`.

Click demo to explore an example Scalene profile.